@@ -245,6 +245,7 @@ def _search_derived(
     search_public_key: bool,
     search_private_key: bool,
     search_address: bool,
+    prefix: str,
 ) -> List[str]:  # Return a subset of search_terms that were found
     """
     Performs a shallow search of keys derived from the current sk for items matching
@@ -291,7 +292,7 @@ def _search_derived(
         if search_address:
             # Generate a wallet address using the standard p2_delegated_puzzle_or_hidden_puzzle puzzle
             # TODO: consider generating addresses using other puzzles
-            address = encode_puzzle_hash(create_puzzlehash_for_pk(child_pk), "hcx")
+            address = encode_puzzle_hash(create_puzzlehash_for_pk(child_pk), prefix)
 
         for term in remaining_search_terms:
             found_item: Any = None
@@ -344,6 +345,7 @@ def _search_derived(
 
 
 def search_derive(
+    root_path: Path,
     private_key: Optional[PrivateKey],
     search_terms: Tuple[str, ...],
     limit: int,
@@ -351,6 +353,7 @@ def search_derive(
     show_progress: bool,
     search_types: Tuple[str, ...],
     derive_from_hd_path: Optional[str],
+    prefix: Optional[str],
 ) -> bool:
     """
     Searches for items derived from the provided private key, or if not specified,
@@ -366,6 +369,11 @@ def search_derive(
     search_public_key = "public_key" in search_types
     search_private_key = "private_key" in search_types
 
+    if prefix is None:
+        config: Dict = load_config(root_path, "config.yaml")
+        selected: str = config["selected_network"]
+        prefix = config["network_overrides"]["config"][selected]["address_prefix"]
+
     if "all" in search_types:
         search_address = True
         search_public_key = True
@@ -402,6 +410,7 @@ def search_derive(
                 search_public_key,
                 search_private_key,
                 search_address,
+                prefix,
             )
 
             # Update remaining_search_terms
@@ -447,6 +456,7 @@ def search_derive(
                     search_public_key,
                     search_private_key,
                     search_address,
+                    prefix,
                 )
 
                 # Update remaining_search_terms
