@@ -8,6 +8,7 @@ from typing import Any, Awaitable, Callable, Dict, List, Optional, Tuple, Union
 
 import aiohttp
 
+from chinilla.cmds.cmds_util import transaction_submitted_msg, transaction_status_msg
 from chinilla.cmds.show import print_connections
 from chinilla.cmds.units import units
 from chinilla.rpc.wallet_rpc_client import WalletRpcClient
@@ -17,8 +18,7 @@ from chinilla.types.blockchain_format.sized_bytes import bytes32
 from chinilla.util.bech32m import bech32_decode, decode_puzzle_hash, encode_puzzle_hash
 from chinilla.util.config import load_config
 from chinilla.util.default_root import DEFAULT_ROOT_PATH
-from chinilla.util.ints import uint16, uint32, uint64
-from chinilla.cmds.cmds_util import transaction_submitted_msg, transaction_status_msg
+from chinilla.util.ints import uint16, uint32, uint64, uint128
 from chinilla.wallet.did_wallet.did_info import DID_HRP
 from chinilla.wallet.nft_wallet.nft_info import NFT_HRP, NFTInfo
 from chinilla.wallet.trade_record import TradeRecord
@@ -30,7 +30,6 @@ from chinilla.wallet.util.wallet_types import WalletType
 
 CATNameResolver = Callable[[bytes32], Awaitable[Optional[Tuple[Optional[uint32], str]]]]
 
-
 transaction_type_descriptions = {
     TransactionType.INCOMING_TX: "received",
     TransactionType.OUTGOING_TX: "sent",
@@ -192,6 +191,7 @@ async def send(args: dict, wallet_client: WalletRpcClient, fingerprint: int) ->
     fee = Decimal(args["fee"])
     address = args["address"]
     override = args["override"]
+    min_coin_amount = Decimal(args["min_coin_amount"])
     memo = args["memo"]
     if memo is None:
         memos = None
@@ -213,14 +213,21 @@ async def send(args: dict, wallet_client: WalletRpcClient, fingerprint: int) ->
 
     final_fee = uint64(int(fee * units["chinilla"]))
     final_amount: uint64
+    final_min_coin_amount: uint128
     if typ == WalletType.STANDARD_WALLET:
         final_amount = uint64(int(amount * units["chinilla"]))
+        final_min_coin_amount = uint128(int(min_coin_amount * units["chinilla"]))
         print("Submitting transaction...")
-        res = await wallet_client.send_transaction(str(wallet_id), final_amount, address, final_fee, memos)
+        res = await wallet_client.send_transaction(
+            str(wallet_id), final_amount, address, final_fee, memos, final_min_coin_amount
+        )
     elif typ == WalletType.CAT:
         final_amount = uint64(int(amount * units["cat"]))
+        final_min_coin_amount = uint128(int(min_coin_amount * units["cat"]))
         print("Submitting transaction...")
-        res = await wallet_client.cat_spend(str(wallet_id), final_amount, address, final_fee, memos)
+        res = await wallet_client.cat_spend(
+            str(wallet_id), final_amount, address, final_fee, memos, final_min_coin_amount
+        )
     else:
         print("Only standard wallet and CAT wallets are supported")
         return
@@ -252,6 +259,19 @@ async def delete_unconfirmed_transactions(args: dict, wallet_client: WalletRpcCl
     print(f"Successfully deleted all unconfirmed transactions for wallet id {wallet_id} on key {fingerprint}")
 
 
+async def get_derivation_index(args: dict, wallet_client: WalletRpcClient, fingerprint: int) -> None:
+    res = await wallet_client.get_current_derivation_index()
+    print(f"Last derivation index: {res}")
+
+
+async def update_derivation_index(args: dict, wallet_client: WalletRpcClient, fingerprint: int) -> None:
+    index = args["index"]
+    print("Updating derivation index... This may take a while.")
+    res = await wallet_client.extend_derivation_index(index)
+    print(f"Updated derivation index: {res}")
+    print("Your balances may take a while to update.")
+
+
 async def add_token(args: dict, wallet_client: WalletRpcClient, fingerprint: int) -> None:
     asset_id = args["asset_id"]
     token_name = args["token_name"]
@@ -510,16 +530,50 @@ async def take_offer(args: dict, wallet_client: WalletRpcClient, fingerprint: in
         print("Please enter a valid offer file or hex blob")
         return
 
-    offered, requested, _ = offer.summary()
+    offered, requested, driver_dict = offer.summary()
     cat_name_resolver = wallet_client.cat_asset_id_to_name
     print("Summary:")
     print("  OFFERED:")
     await print_offer_summary(cat_name_resolver, offered)
     print("  REQUESTED:")
     await print_offer_summary(cat_name_resolver, requested)
+
+    print()
+
+    nft_coin_id: Optional[bytes32] = nft_coin_id_supporting_royalties_from_offer(driver_dict)
+    nft_royalty_percentage: int = (
+        0 if nft_coin_id is None else await get_nft_royalty_percentage(nft_coin_id, wallet_client)
+    )
+    nft_total_amount_requested_str: Optional[str] = None
+    if nft_coin_id is not None and nft_royalty_percentage > 0:
+        print("NFT Royalty Fee:")
+        nft_royalty_asset_id, nft_royalty_amount, nft_total_amount_requested = calculate_nft_royalty_amount(
+            offered, requested, nft_coin_id, nft_royalty_percentage
+        )
+        nft_royalty_currency: str = "Unknown CAT"
+        if nft_royalty_asset_id == "hcx":
+            nft_royalty_currency = "HCX"
+        else:
+            result = await cat_name_resolver(bytes32.fromhex(nft_royalty_asset_id))
+            if result is not None:
+                nft_royalty_currency = result[1]
+
+        nft_royalty_divisor = units["chinilla"] if nft_royalty_asset_id == "hcx" else units["cat"]
+        nft_total_amount_requested_str = (
+            f"{Decimal(nft_total_amount_requested) / nft_royalty_divisor} {nft_royalty_currency}"
+        )
+        print(
+            f"      {Decimal(nft_royalty_amount) / nft_royalty_divisor} {nft_royalty_currency} "
+            f"({nft_royalty_amount} mojos)"
+        )
+
     print(f"Included Fees: {Decimal(offer.bundle.fees()) / units['chinilla']}")
 
+    if nft_total_amount_requested_str is not None:
+        print(f"Total Amount Requested: {nft_total_amount_requested_str}")
+
     if not examine_only:
+        print()
         confirmation = input("Would you like to take this offer? (y/n): ")
         if confirmation in ["y", "yes"]:
             trade_record = await wallet_client.take_offer(offer, fee=fee)
@@ -552,7 +606,7 @@ def wallet_coin_unit(typ: WalletType, address_prefix: str) -> Tuple[str, int]:
 
 
 def print_balance(amount: int, scale: int, address_prefix: str) -> str:
-    ret = f"{amount/scale} {address_prefix} "
+    ret = f"{amount / scale} {address_prefix} "
     if scale > 1:
         ret += f"({amount} vojo)"
     return ret
@@ -647,7 +701,7 @@ async def get_wallet(wallet_client: WalletRpcClient, fingerprint: int = None) ->
                 current_sync_status = "Not Synced"
         print("Wallet keys:")
         for i, fp in enumerate(fingerprints):
-            row: str = f"{i+1}) "
+            row: str = f"{i + 1}) "
             row += "* " if fp == logged_in_fingerprint else spacing
             row += f"{fp}"
             if fp == logged_in_fingerprint and len(current_sync_status) > 0:
@@ -771,8 +825,8 @@ async def mint_nft(args: Dict, wallet_client: WalletRpcClient, fingerprint: int)
     metadata_uris = args["metadata_uris"]
     license_hash = args["license_hash"]
     license_uris = args["license_uris"]
-    series_total = args["series_total"]
-    series_number = args["series_number"]
+    edition_count = args["edition_count"]
+    edition_number = args["edition_number"]
     fee: int = int(Decimal(args["fee"]) * units["chinilla"])
     royalty_percentage = args["royalty_percentage"]
     try:
@@ -800,8 +854,8 @@ async def mint_nft(args: Dict, wallet_client: WalletRpcClient, fingerprint: int)
             metadata_uris,
             license_hash,
             license_uris,
-            series_total,
-            series_number,
+            edition_count,
+            edition_number,
             fee,
             royalty_percentage,
             did_id,
@@ -924,3 +978,40 @@ async def get_nft_info(args: Dict, wallet_client: WalletRpcClient, fingerprint:
         print_nft_info(nft_info)
     except Exception as e:
         print(f"Failed to get NFT info: {e}")
+
+
+async def get_nft_royalty_percentage(nft_coin_id: bytes32, wallet_client: WalletRpcClient) -> int:
+    info = NFTInfo.from_json_dict((await wallet_client.get_nft_info(nft_coin_id.hex()))["nft_info"])
+    return info.royalty_percentage if info.royalty_percentage is not None else 0
+
+
+def calculate_nft_royalty_amount(
+    offered: Dict[str, Any], requested: Dict[str, Any], nft_coin_id: bytes32, nft_royalty_percentage: int
+) -> Tuple[str, int, int]:
+    nft_asset_id = nft_coin_id.hex()
+    amount_dict: Dict[str, Any] = requested if nft_asset_id in offered else offered
+    amounts: List[Tuple[str, int]] = list(amount_dict.items())
+
+    if len(amounts) != 1 or not isinstance(amounts[0][1], int):
+        raise ValueError("Royalty enabled NFTs only support offering/requesting one NFT for one currency")
+
+    royalty_amount: uint64 = uint64(amounts[0][1] * nft_royalty_percentage / 10000)
+    royalty_asset_id = amounts[0][0]
+    total_amount_requested = (requested[royalty_asset_id] if amount_dict == requested else 0) + royalty_amount
+    return royalty_asset_id, royalty_amount, total_amount_requested
+
+
+def driver_dict_asset_is_nft_supporting_royalties(driver_dict: Dict[str, Any], asset_id: str) -> bool:
+    asset_dict: Dict[str, Any] = driver_dict[asset_id]
+    return (
+        asset_dict.get("type") == "singleton"
+        and asset_dict.get("also", {}).get("type") == "metadata"
+        and asset_dict.get("also", {}).get("also", {}).get("type") == "ownership"
+    )
+
+
+def nft_coin_id_supporting_royalties_from_offer(driver_dict: Dict[str, Any]) -> Optional[bytes32]:
+    nft_asset_id: Optional[str] = next(
+        (key for key in driver_dict.keys() if driver_dict_asset_is_nft_supporting_royalties(driver_dict, key)), None
+    )
+    return bytes32.fromhex(nft_asset_id) if nft_asset_id is not None else None
