@@ -11,7 +11,7 @@ from chinilla.types.blockchain_format.sized_bytes import bytes32
 from chinilla.types.spend_bundle import SpendBundle
 from chinilla.util.db_wrapper import DBWrapper
 from chinilla.util.hash import std_hash
-from chinilla.util.ints import uint32, uint64
+from chinilla.util.ints import uint32, uint64, uint128
 from chinilla.wallet.nft_wallet.nft_wallet import NFTWallet
 from chinilla.wallet.outer_puzzles import AssetType
 from chinilla.wallet.payment import Payment
@@ -297,13 +297,15 @@ class TradeManager:
         driver_dict: Optional[Dict[bytes32, PuzzleInfo]] = None,
         fee: uint64 = uint64(0),
         validate_only: bool = False,
+        min_coin_amount: Optional[uint128] = None,
     ) -> Tuple[bool, Optional[TradeRecord], Optional[str]]:
         if driver_dict is None:
             driver_dict = {}
-        success, created_offer, error = await self._create_offer_for_ids(offer, driver_dict, fee=fee)
+        success, created_offer, error = await self._create_offer_for_ids(
+            offer, driver_dict, fee=fee, min_coin_amount=min_coin_amount
+        )
         if not success or created_offer is None:
             raise Exception(f"Error creating offer: {error}")
-
         now = uint64(int(time.time()))
         trade_offer: TradeRecord = TradeRecord(
             confirmed_at_index=uint32(0),
@@ -329,6 +331,7 @@ class TradeManager:
         offer_dict: Dict[Union[int, bytes32], int],
         driver_dict: Optional[Dict[bytes32, PuzzleInfo]] = None,
         fee: uint64 = uint64(0),
+        min_coin_amount: Optional[uint128] = None,
     ) -> Tuple[bool, Optional[Offer], Optional[str]]:
         """
         Offer is dictionary of wallet ids and amount
@@ -378,7 +381,7 @@ class TradeManager:
                         wallet = await self.wallet_state_manager.get_wallet_for_asset_id(asset_id.hex())
                     if not callable(getattr(wallet, "get_coins_to_offer", None)):  # ATTENTION: new wallets
                         raise ValueError(f"Cannot offer coins from wallet id {wallet.id()}")
-                    coins_to_offer[id] = await wallet.get_coins_to_offer(asset_id, uint64(abs(amount)))
+                    coins_to_offer[id] = await wallet.get_coins_to_offer(asset_id, uint64(abs(amount)), min_coin_amount)
                 elif amount == 0:
                     raise ValueError("You cannot offer nor request 0 amount of something")
 
@@ -582,7 +585,9 @@ class TradeManager:
 
         return txs
 
-    async def respond_to_offer(self, offer: Offer, fee=uint64(0)) -> Tuple[bool, Optional[TradeRecord], Optional[str]]:
+    async def respond_to_offer(
+        self, offer: Offer, fee=uint64(0), min_coin_amount: Optional[uint128] = None
+    ) -> Tuple[bool, Optional[TradeRecord], Optional[str]]:
         take_offer_dict: Dict[Union[bytes32, int], int] = {}
         arbitrage: Dict[Optional[bytes32], int] = offer.arbitrage()
 
@@ -605,7 +610,9 @@ class TradeManager:
         valid: bool = await self.check_offer_validity(offer)
         if not valid:
             return False, None, "This offer is no longer valid"
-        success, take_offer, error = await self._create_offer_for_ids(take_offer_dict, offer.driver_dict, fee=fee)
+        success, take_offer, error = await self._create_offer_for_ids(
+            take_offer_dict, offer.driver_dict, fee=fee, min_coin_amount=min_coin_amount
+        )
         if not success or take_offer is None:
             return False, None, error
 
