@@ -23,7 +23,6 @@ from tests.setup_nodes import test_constants
 from chinilla.types.blockchain_format.sized_bytes import bytes32
 from tests.util.db_connection import DBConnection
 
-
 constants = test_constants
 
 WALLET_A = WalletTool(constants)
@@ -51,8 +50,7 @@ def get_future_reward_coins(block: FullBlock) -> Tuple[Coin, Coin]:
 
 class TestCoinStoreWithBlocks:
     @pytest.mark.asyncio
-    @pytest.mark.parametrize("cache_size", [0])
-    async def test_basic_coin_store(self, cache_size: uint32, db_version, softfork_height, bt):
+    async def test_basic_coin_store(self, db_version, softfork_height, bt):
         wallet_a = WALLET_A
         reward_ph = wallet_a.get_new_puzzlehash()
 
@@ -76,7 +74,7 @@ class TestCoinStoreWithBlocks:
         )
 
         async with DBConnection(db_version) as db_wrapper:
-            coin_store = await CoinStore.create(db_wrapper, cache_size=cache_size)
+            coin_store = await CoinStore.create(db_wrapper)
 
             blocks = bt.get_consecutive_blocks(
                 10,
@@ -129,32 +127,43 @@ class TestCoinStoreWithBlocks:
                                     tx_removals,
                                 )
 
+                    all_records = set()
                     for expected_coin in should_be_included_prev:
                         # Check that the coinbase rewards are added
                         record = await coin_store.get_coin_record(expected_coin.name())
                         assert record is not None
                         assert not record.spent
                         assert record.coin == expected_coin
+                        all_records.add(record)
                     for coin_name in tx_removals:
                         # Check that the removed coins are set to spent
                         record = await coin_store.get_coin_record(coin_name)
                         assert record.spent
+                        all_records.add(record)
                     for coin in tx_additions:
                         # Check that the added coins are added
                         record = await coin_store.get_coin_record(coin.name())
                         assert not record.spent
                         assert coin == record.coin
+                        all_records.add(record)
+
+                    db_records = await coin_store.get_coin_records(
+                        [c.name() for c in list(should_be_included_prev) + tx_additions] + tx_removals
+                    )
+                    assert len(db_records) == len(should_be_included_prev) + len(tx_removals) + len(tx_additions)
+                    assert len(db_records) == len(all_records)
+                    for record in db_records:
+                        assert record in all_records
 
                     should_be_included_prev = should_be_included.copy()
                     should_be_included = set()
 
     @pytest.mark.asyncio
-    @pytest.mark.parametrize("cache_size", [0, 10, 100000])
-    async def test_set_spent(self, cache_size: uint32, db_version, bt):
+    async def test_set_spent(self, db_version, bt):
         blocks = bt.get_consecutive_blocks(9, [])
 
         async with DBConnection(db_version) as db_wrapper:
-            coin_store = await CoinStore.create(db_wrapper, cache_size=cache_size)
+            coin_store = await CoinStore.create(db_wrapper)
 
             # Save/get block
             for block in blocks:
@@ -181,14 +190,6 @@ class TestCoinStoreWithBlocks:
                         for r in records:
                             assert (await coin_store.get_coin_record(r.name)) is not None
 
-                        if cache_size > 0:
-                            # Check that we can't spend a coin twice in cache
-                            with pytest.raises(ValueError, match="Coin already spent"):
-                                await coin_store._set_spent([r.name for r in records], block.height)
-
-                            for r in records:
-                                coin_store.coin_record_cache.remove(r.name)
-
                         # Check that we can't spend a coin twice in DB
                         with pytest.raises(ValueError, match="Invalid operation to set spent"):
                             await coin_store._set_spent([r.name for r in records], block.height)
@@ -231,43 +232,75 @@ class TestCoinStoreWithBlocks:
         assert test_excercised
 
     @pytest.mark.asyncio
-    @pytest.mark.parametrize("cache_size", [0, 10, 100000])
-    async def test_rollback(self, cache_size: uint32, db_version, bt):
+    async def test_rollback(self, db_version, bt):
         blocks = bt.get_consecutive_blocks(20)
 
         async with DBConnection(db_version) as db_wrapper:
-            coin_store = await CoinStore.create(db_wrapper, cache_size=uint32(cache_size))
+            coin_store = await CoinStore.create(db_wrapper)
 
-            records: List[CoinRecord] = []
+            selected_coin: Optional[CoinRecord] = None
+            all_coins: List[Coin] = []
 
             for block in blocks:
+                all_coins += list(block.get_included_reward_coins())
                 if block.is_transaction_block():
                     removals: List[bytes32] = []
                     additions: List[Coin] = []
+                    assert block.foliage_transaction_block is not None
+                    await coin_store.new_block(
+                        block.height,
+                        block.foliage_transaction_block.timestamp,
+                        block.get_included_reward_coins(),
+                        additions,
+                        removals,
+                    )
+                    coins = list(block.get_included_reward_coins())
+                    records: List[CoinRecord] = [await coin_store.get_coin_record(coin.name()) for coin in coins]
 
-                    if block.is_transaction_block():
-                        assert block.foliage_transaction_block is not None
-                        await coin_store.new_block(
-                            block.height,
-                            block.foliage_transaction_block.timestamp,
-                            block.get_included_reward_coins(),
-                            additions,
-                            removals,
-                        )
+                    spend_selected_coin = selected_coin is not None
+                    if block.height != 0 and selected_coin is None:
+                        # Select the first CoinRecord which will be spent at the next transaction block.
+                        selected_coin = records[0]
+                        await coin_store._set_spent([r.name for r in records[1:]], block.height)
+                    else:
+                        await coin_store._set_spent([r.name for r in records], block.height)
 
-                    coins = block.get_included_reward_coins()
-                    records = [await coin_store.get_coin_record(coin.name()) for coin in coins]
+                    if spend_selected_coin:
+                        assert selected_coin is not None
+                        await coin_store._set_spent([selected_coin.name], block.height)
 
-                    await coin_store._set_spent([r.name for r in records], block.height)
-
-                    records = [await coin_store.get_coin_record(coin.name()) for coin in coins]
+                    records = [await coin_store.get_coin_record(coin.name()) for coin in coins]  # update coin records
                     for record in records:
                         assert record is not None
-                        assert record.spent
-                        assert record.spent_block_index == block.height
+                        if (
+                            selected_coin is not None
+                            and selected_coin.name == record.name
+                            and not selected_coin.confirmed_block_index < block.height
+                        ):
+                            assert not record.spent
+                        else:
+                            assert record.spent
+                            assert record.spent_block_index == block.height
 
-            reorg_index = 8
-            await coin_store.rollback_to_block(reorg_index)
+                    if spend_selected_coin:
+                        break
+
+            assert selected_coin is not None
+            reorg_index = selected_coin.confirmed_block_index
+
+            # Get all CoinRecords.
+            all_records: List[CoinRecord] = [await coin_store.get_coin_record(coin.name()) for coin in all_coins]
+
+            # The reorg will revert the creation and spend of many coins. It will also revert the spend (but not the
+            # creation) of the selected coin.
+            changed_records = await coin_store.rollback_to_block(reorg_index)
+            changed_coin_records = [cr.coin for cr in changed_records]
+            assert selected_coin in changed_records
+            for coin_record in all_records:
+                if coin_record.confirmed_block_index > reorg_index:
+                    assert coin_record.coin in changed_coin_records
+                if coin_record.spent_block_index > reorg_index:
+                    assert coin_record.coin in changed_coin_records
 
             for block in blocks:
                 if block.is_transaction_block():
@@ -277,20 +310,19 @@ class TestCoinStoreWithBlocks:
                     if block.height <= reorg_index:
                         for record in records:
                             assert record is not None
-                            assert record.spent
+                            assert record.spent == (record.name != selected_coin.name)
                     else:
                         for record in records:
                             assert record is None
 
     @pytest.mark.asyncio
-    @pytest.mark.parametrize("cache_size", [0, 10, 100000])
-    async def test_basic_reorg(self, cache_size: uint32, tmp_dir, db_version, bt):
+    async def test_basic_reorg(self, tmp_dir, db_version, bt):
 
         async with DBConnection(db_version) as db_wrapper:
             initial_block_count = 30
             reorg_length = 15
             blocks = bt.get_consecutive_blocks(initial_block_count)
-            coin_store = await CoinStore.create(db_wrapper, cache_size=uint32(cache_size))
+            coin_store = await CoinStore.create(db_wrapper)
             store = await BlockStore.create(db_wrapper)
             hint_store = await HintStore.create(db_wrapper)
             b: Blockchain = await Blockchain.create(coin_store, store, test_constants, hint_store, tmp_dir, 2)
@@ -344,8 +376,7 @@ class TestCoinStoreWithBlocks:
                 b.shut_down()
 
     @pytest.mark.asyncio
-    @pytest.mark.parametrize("cache_size", [0, 10, 100000])
-    async def test_get_puzzle_hash(self, cache_size: uint32, tmp_dir, db_version, bt):
+    async def test_get_puzzle_hash(self, tmp_dir, db_version, bt):
         async with DBConnection(db_version) as db_wrapper:
             num_blocks = 20
             farmer_ph = bytes32(32 * b"0")
@@ -356,7 +387,7 @@ class TestCoinStoreWithBlocks:
                 pool_reward_puzzle_hash=pool_ph,
                 guarantee_transaction_block=True,
             )
-            coin_store = await CoinStore.create(db_wrapper, cache_size=uint32(cache_size))
+            coin_store = await CoinStore.create(db_wrapper)
             store = await BlockStore.create(db_wrapper)
             hint_store = await HintStore.create(db_wrapper)
             b: Blockchain = await Blockchain.create(coin_store, store, test_constants, hint_store, tmp_dir, 2)
@@ -375,8 +406,7 @@ class TestCoinStoreWithBlocks:
             b.shut_down()
 
     @pytest.mark.asyncio
-    @pytest.mark.parametrize("cache_size", [0, 10, 100000])
-    async def test_get_coin_states(self, cache_size: uint32, tmp_dir, db_version):
+    async def test_get_coin_states(self, tmp_dir, db_version):
         async with DBConnection(db_version) as db_wrapper:
             crs = [
                 CoinRecord(
@@ -398,7 +428,7 @@ class TestCoinStoreWithBlocks:
                 )
                 for i in range(1, 301)
             ]
-            coin_store = await CoinStore.create(db_wrapper, cache_size=uint32(cache_size))
+            coin_store = await CoinStore.create(db_wrapper)
             await coin_store._add_coin_records(crs)
 
             assert len(await coin_store.get_coin_states_by_puzzle_hashes(True, [std_hash(b"2")], 0)) == 300
