@@ -15,11 +15,10 @@ from tests.block_tools import test_constants
 from tests.setup_nodes import setup_harvester_farmer
 
 
-async def establish_connection(server: ChinillaServer, self_hostname: str, ssl_context) -> bool:
+async def establish_connection(server: ChinillaServer, self_hostname: str, ssl_context) -> None:
     timeout = aiohttp.ClientTimeout(total=10)
-    session = aiohttp.ClientSession(timeout=timeout)
     dummy_port = 5  # this does not matter
-    try:
+    async with aiohttp.ClientSession(timeout=timeout) as session:
         incoming_queue: asyncio.Queue = asyncio.Queue()
         url = f"wss://{self_hostname}:{server._port}/ws"
         ws = await session.ws_connect(url, autoclose=False, autoping=True, ssl=ssl_context)
@@ -37,12 +36,7 @@ async def establish_connection(server: ChinillaServer, self_hostname: str, ssl_c
             100,
             30,
         )
-        handshake = await wsc.perform_handshake(server._network_id, protocol_version, dummy_port, NodeType.FULL_NODE)
-        await session.close()
-        return handshake
-    except Exception:
-        await session.close()
-        return False
+        await wsc.perform_handshake(server._network_id, protocol_version, dummy_port, NodeType.FULL_NODE)
 
 
 @pytest_asyncio.fixture(scope="function")
@@ -80,8 +74,7 @@ class TestSSL:
         ssl_context = ssl_context_for_client(
             farmer_server.ca_private_crt_path, farmer_server.ca_private_key_path, priv_crt, priv_key
         )
-        connected = await establish_connection(farmer_server, self_hostname, ssl_context)
-        assert connected is True
+        await establish_connection(farmer_server, self_hostname, ssl_context)
 
         # Create not authenticated cert
         pub_crt = farmer_server._private_key_path.parent / "non_valid.crt"
@@ -95,13 +88,13 @@ class TestSSL:
         ssl_context = ssl_context_for_client(
             farmer_server.chinilla_ca_crt_path, farmer_server.chinilla_ca_key_path, pub_crt, pub_key
         )
-        connected = await establish_connection(farmer_server, self_hostname, ssl_context)
-        assert connected is False
+        with pytest.raises(aiohttp.ClientConnectorCertificateError):
+            await establish_connection(farmer_server, self_hostname, ssl_context)
         ssl_context = ssl_context_for_client(
             farmer_server.ca_private_crt_path, farmer_server.ca_private_key_path, pub_crt, pub_key
         )
-        connected = await establish_connection(farmer_server, self_hostname, ssl_context)
-        assert connected is False
+        with pytest.raises(aiohttp.ServerDisconnectedError):
+            await establish_connection(farmer_server, self_hostname, ssl_context)
 
     @pytest.mark.asyncio
     async def test_full_node(self, wallet_node_sim_and_wallet, self_hostname):
@@ -121,8 +114,7 @@ class TestSSL:
         ssl_context = ssl_context_for_client(
             full_node_server.chinilla_ca_crt_path, full_node_server.chinilla_ca_key_path, pub_crt, pub_key
         )
-        connected = await establish_connection(full_node_server, self_hostname, ssl_context)
-        assert connected is True
+        await establish_connection(full_node_server, self_hostname, ssl_context)
 
     @pytest.mark.asyncio
     async def test_wallet(self, wallet_node_sim_and_wallet, self_hostname):
@@ -141,8 +133,8 @@ class TestSSL:
         ssl_context = ssl_context_for_client(
             wallet_server.chinilla_ca_crt_path, wallet_server.chinilla_ca_key_path, pub_crt, pub_key
         )
-        connected = await establish_connection(wallet_server, self_hostname, ssl_context)
-        assert connected is False
+        with pytest.raises(aiohttp.ClientConnectorError):
+            await establish_connection(wallet_server, self_hostname, ssl_context)
 
         # Not even signed by private cert
         priv_crt = wallet_server._private_key_path.parent / "valid.crt"
@@ -156,8 +148,8 @@ class TestSSL:
         ssl_context = ssl_context_for_client(
             wallet_server.ca_private_crt_path, wallet_server.ca_private_key_path, priv_crt, priv_key
         )
-        connected = await establish_connection(wallet_server, self_hostname, ssl_context)
-        assert connected is False
+        with pytest.raises(aiohttp.ClientConnectorError):
+            await establish_connection(wallet_server, self_hostname, ssl_context)
 
     @pytest.mark.asyncio
     async def test_harvester(self, harvester_farmer, self_hostname):
@@ -176,8 +168,8 @@ class TestSSL:
         ssl_context = ssl_context_for_client(
             harvester_server.chinilla_ca_crt_path, harvester_server.chinilla_ca_key_path, pub_crt, pub_key
         )
-        connected = await establish_connection(harvester_server, self_hostname, ssl_context)
-        assert connected is False
+        with pytest.raises(aiohttp.ClientConnectorError):
+            await establish_connection(harvester_server, self_hostname, ssl_context)
 
         # Not even signed by private cert
         priv_crt = harvester_server._private_key_path.parent / "valid.crt"
@@ -191,8 +183,8 @@ class TestSSL:
         ssl_context = ssl_context_for_client(
             harvester_server.ca_private_crt_path, harvester_server.ca_private_key_path, priv_crt, priv_key
         )
-        connected = await establish_connection(harvester_server, self_hostname, ssl_context)
-        assert connected is False
+        with pytest.raises(aiohttp.ClientConnectorError):
+            await establish_connection(harvester_server, self_hostname, ssl_context)
 
     @pytest.mark.asyncio
     async def test_introducer(self, introducer, self_hostname):
@@ -210,8 +202,7 @@ class TestSSL:
         ssl_context = ssl_context_for_client(
             introducer_server.chinilla_ca_crt_path, introducer_server.chinilla_ca_key_path, pub_crt, pub_key
         )
-        connected = await establish_connection(introducer_server, self_hostname, ssl_context)
-        assert connected is True
+        await establish_connection(introducer_server, self_hostname, ssl_context)
 
     @pytest.mark.asyncio
     async def test_timelord(self, timelord, self_hostname):
@@ -229,8 +220,8 @@ class TestSSL:
         ssl_context = ssl_context_for_client(
             timelord_server.chinilla_ca_crt_path, timelord_server.chinilla_ca_key_path, pub_crt, pub_key
         )
-        connected = await establish_connection(timelord_server, self_hostname, ssl_context)
-        assert connected is False
+        with pytest.raises(aiohttp.ClientConnectorError):
+            await establish_connection(timelord_server, self_hostname, ssl_context)
 
         # Not even signed by private cert
         priv_crt = timelord_server._private_key_path.parent / "valid.crt"
@@ -244,5 +235,5 @@ class TestSSL:
         ssl_context = ssl_context_for_client(
             timelord_server.ca_private_crt_path, timelord_server.ca_private_key_path, priv_crt, priv_key
         )
-        connected = await establish_connection(timelord_server, self_hostname, ssl_context)
-        assert connected is False
+        with pytest.raises(aiohttp.ClientConnectorError):
+            await establish_connection(timelord_server, self_hostname, ssl_context)
