@@ -1,6 +1,7 @@
 import asyncio
 import time
-from typing import List, Tuple
+from pathlib import Path
+from typing import Any, Dict, List, Tuple
 
 import pytest
 
@@ -18,7 +19,7 @@ from chinilla.wallet.transaction_record import TransactionRecord
 from chinilla.wallet.util.compute_memos import compute_memos
 from chinilla.wallet.util.transaction_type import TransactionType
 from chinilla.wallet.util.wallet_types import AmountWithPuzzlehash
-from chinilla.wallet.wallet_node import WalletNode
+from chinilla.wallet.wallet_node import WalletNode, get_wallet_db_path
 from chinilla.wallet.wallet_state_manager import WalletStateManager
 from tests.pools.test_pool_rpc import wallet_is_synced
 from tests.time_out_assert import time_out_assert, time_out_assert_not_none
@@ -910,3 +911,59 @@ class TestWalletSimulator:
 
         await time_out_assert(5, wallet.get_confirmed_balance, funds - AMOUNT_TO_SEND)
         await time_out_assert(5, wallet.get_unconfirmed_balance, funds - AMOUNT_TO_SEND)
+
+
+def test_get_wallet_db_path_v2_r1() -> None:
+    root_path: Path = Path("/x/y/z/.chinilla/vanillanet")
+    config: Dict[str, Any] = {
+        "database_path": "wallet/db/blockchain_wallet_v2_r1_CHALLENGE_KEY.sqlite",
+        "selected_network": "vanillanet",
+    }
+    fingerprint: str = "1234567890"
+    wallet_db_path: Path = get_wallet_db_path(root_path, config, fingerprint)
+
+    assert wallet_db_path == Path(
+        "/x/y/z/.chinilla/vanillanet/wallet/db/blockchain_wallet_v2_r1_vanillanet_1234567890.sqlite"
+    )
+
+
+def test_get_wallet_db_path_v2() -> None:
+    root_path: Path = Path("/x/y/z/.chinilla/vanillanet")
+    config: Dict[str, Any] = {
+        "database_path": "wallet/db/blockchain_wallet_v2_CHALLENGE_KEY.sqlite",
+        "selected_network": "vanillanet",
+    }
+    fingerprint: str = "1234567890"
+    wallet_db_path: Path = get_wallet_db_path(root_path, config, fingerprint)
+
+    assert wallet_db_path == Path(
+        "/x/y/z/.chinilla/vanillanet/wallet/db/blockchain_wallet_v2_r1_vanillanet_1234567890.sqlite"
+    )
+
+
+def test_get_wallet_db_path_v1() -> None:
+    root_path: Path = Path("/x/y/z/.chinilla/vanillanet")
+    config: Dict[str, Any] = {
+        "database_path": "wallet/db/blockchain_wallet_v1_CHALLENGE_KEY.sqlite",
+        "selected_network": "vanillanet",
+    }
+    fingerprint: str = "1234567890"
+    wallet_db_path: Path = get_wallet_db_path(root_path, config, fingerprint)
+
+    assert wallet_db_path == Path(
+        "/x/y/z/.chinilla/vanillanet/wallet/db/blockchain_wallet_v2_r1_vanillanet_1234567890.sqlite"
+    )
+
+
+def test_get_wallet_db_path_testnet() -> None:
+    root_path: Path = Path("/x/y/z/.chinilla/testnet")
+    config: Dict[str, Any] = {
+        "database_path": "wallet/db/blockchain_wallet_v2_CHALLENGE_KEY.sqlite",
+        "selected_network": "testnet",
+    }
+    fingerprint: str = "1234567890"
+    wallet_db_path: Path = get_wallet_db_path(root_path, config, fingerprint)
+
+    assert wallet_db_path == Path(
+        "/x/y/z/.chinilla/testnet/wallet/db/blockchain_wallet_v2_r1_testnet_1234567890.sqlite"
+    )
